%bcond doc_pdf 0

Name:           python-param
%global shortcommit 782a03c
Version:        1.13.0
Release:    2%{?dist}
Summary:        Make your Python code clearer and more reliable by declaring Parameters

License:        BSD-3-Clause
URL:            https://github.com/holoviz/param
Source0:         %{url}/archive/v%{version}/param-%{version}.tar.gz

BuildArch:      noarch

ExcludeArch:    %{ix86}

BuildRequires:  python3-devel

%if %{with doc_pdf}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
%endif

BuildRequires:  python3dist(pytest)

%global common_description %{expand:
Param is a library providing Parameters: Python attributes extended to have
features such as type and range checking, dynamically generated values,
documentation strings, default values, etc., each of which is inherited from
parent classes if not specified in a subclass.

Documentation and examples may be found at https://param.holoviz.org.}

%description %{common_description}


%package -n python3-param
Summary:        %{summary}

Provides:       bundled(python3dist(autover)) = 0.2.5

%description -n python3-param %{common_description}


%package doc
Summary:        Documentation and examples for param

%description doc %{common_description}


%prep
%autosetup -n param-%{version}

cat > param/.version <<EOF
{"git_describe": "v%{version}-0-g%{shortcommit}", "version_string": "%{version}"}
EOF

sed -r -i '/\b(flake8|coverage)\b/d' setup.py


%generate_buildrequires
%pyproject_buildrequires -x tests%{?with_doc_pdf:,doc}


%build
%pyproject_wheel

%if %{with doc_pdf}
sphinx-build -b latex -j%{?_smp_build_ncpus} docs %{_vpath_builddir}/_latex
%make_build -C %{_vpath_builddir}/_latex LATEXMKOPTS='-quiet'
%endif


%install
%pyproject_install
%pyproject_save_files param


%check
%pytest


%files -n python3-param -f %{pyproject_files}
%{python3_sitelib}/numbergen/


%files doc
%license LICENSE.txt
%doc README.md
%doc examples/
%if %{with doc_pdf}
%doc {_vpath_builddir}/_latex/param.pdf
%endif


%changelog
* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com>
- Rebuilt for loongarch64

* Wed Jul 17 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.13.0-1
- initial build
